@@ -29,70 +29,66 @@
 #'        |- file2
 #'        +- file3
 #' }
-#' @details The \code{corpus_install} function will assist the installation of a
+#' @details The `corpus_install()` function will assist the installation of a
 #'   corpus. The following scenarios are offered:
 #' \itemize{
-#'   \item{If argument \code{tarball} is a local tarball, the tarball will
+#'   \item{If argument `tarball` is a local tarball, the tarball will
 #'   be extracted and files will be moved.}
-#'   \item{If \code{tarball} is a URL, the tarball will be downloaded from
-#'   the online location. It is possible to state user credentials using the
-#'   arguments \code{user} and \code{password}. Then the aforementioned
-#'   installation (scenario 1) is executed. If argument \code{pkg} is the
-#'   name of an installed package, corpus files will be moved into this
-#'   package.}
-#'   \item{If argument \code{doi} is Document Object Identifier (DOI), the URL
-#'   from which a corpus tarball can be downloaded is derived from the
-#'   information available at that location. The tarball is downloaded and the
-#'   corpus installed. If argument \code{pkg} is defined, files will be moved
-#'   into a R package, the syste registry and corpus directories are used
-#'   otherwise. Note that at this stage, it is assumed that the DOI has been
-#'   awarded by \href{https://zenodo.org/}{Zenodo}}
-#'   \item{If argument \code{pkg} is provided and specifies an R package (and
-#'   \code{tarball} is \code{NULL}), the corpus package available at a
-#'   CRAN-style repository specified by argument \code{repo} will be installed.
-#'   Internally, the \code{install.packages} function is called and further
-#'   arguments can be passed into this function call. This can be used to pass
-#'   user credentials, e.g. by adding \code{method = "wget" extra = "--user
-#'   donald --password duck"}.
-#'   }
+#'   \item{If `tarball` is a URL, the tarball will be downloaded from the online
+#'   location. It is possible to state user credentials using the arguments
+#'   `user` and `password`. Then the aforementioned installation (scenario 1) is
+#'   executed. If argument `pkg` is the name of an installed package, corpus
+#'   files will be moved into this package.}
+#'   \item{If argument `doi` is Document Object Identifier (DOI), the URL from
+#'   which a corpus tarball can be downloaded is derived from the information
+#'   available at that location. The tarball is downloaded and the corpus
+#'   installed. If argument `pkg` is defined, files will be moved into a R
+#'   package, the syste registry and corpus directories are used otherwise. Note
+#'   that at this stage, it is assumed that the DOI has been awarded by
+#'   \href{https://zenodo.org/}{Zenodo}}
+#'   \item{If argument `pkg` is provided and `tarball` is `NULL`, corpora
+#'   included in the package will be installed as system corpora, using the
+#'   storage location specified by `registry_dir`. }
 #' }
 #' If the corpus to be installed is already available, a dialogue will ask the
 #' user whether an existing corpus shall be deleted and installed anew, if
-#' argument \code{ask} is \code{TRUE}.
+#' argument `ask` is `TRUE`.
 #' @param old Name of the (old) corpus.
 #' @param new Name of the (new) corpus.
-#' @param pkg Name of the data package.
+#' @param pkg Name of a package (length-one `character` vector).
 #' @param repo URL of the repository.
 #' @param tarball URL,  S3-URI or local filename of a tarball with a CWB indexed
-#'   corpus. If \code{NULL} (default) and argument \code{doi} is stated, the
+#'   corpus. If `NULL` (default) and argument `doi` is stated, the
 #'   whereabouts of a corpus tarball will be derived from DOI.
 #' @param doi The DOI (Digital Object Identifier) of a corpus deposited at
 #'   Zenodo (e.g. "10.5281/zenodo.3748858".)
-#' @param lib Directory for R packages, defaults to \code{.libPaths()[1]}.
+#' @param lib Directory for R packages, defaults to `.libPaths()[1]`.
 #' @param verbose Logical, whether to be verbose.
-#' @param ask A \code{logical} value, whether to ask for user input when
+#' @param ask A `logical` value, whether to ask for user input when
 #'   choices are required.
 #' @param registry_dir The corpus registry directory. If missing, the result of
 #'   `cwb_registry_dir()`.
 #' @param corpus The ID of a CWB indexed corpus (in upper case).
 #' @param tarfile Filename of tarball.
-#' @param checksum A length-one \code{character} vector with a MD5 checksum to
+#' @param checksum A length-one `character` vector with a MD5 checksum to
 #'   check for the integrity of a downloaded tarball. If the tarball is
-#'   downloaded from Zenodo by stating a DOI (argument \code{doi}), the checksum
+#'   downloaded from Zenodo by stating a DOI (argument `doi`), the checksum
 #'   included in the metadata for the record is used for the check.
 #' @param corpus_dir The directory that contains the data directories of indexed
 #'   corpora. If missing, the value of `cwb_corpus_dir()` will be used.
 #' @param load A `logical` value, whether to load corpus after installation.
-#' @param ... Further parameters that will be passed into
-#'   \code{install.packages}, if argument \code{tarball} is \code{NULL}, or into
-#'   or \code{download.file}, if \code{tarball} is specified.
-#' @param user A user name that can be specified to download a corpus from a password protected site.
-#' @param password A password that can be specified to download a corpus from a password protected site.
+#' @param ... Further parameters that will be passed into `download.file()`, if
+#'   `tarball` is specified.
+#' @param user A user name that can be specified to download a corpus from a
+#'   password protected site.
+#' @param password A password that can be specified to download a corpus from a
+#'   password protected site.
 #' @name corpus_install
-#' @return Logical value \code{TRUE} if installation has been successful, or \code{FALSE} if not.
+#' @return Logical value `TRUE` if installation has been successful, or `FALSE`
+#'   if not.
 #' @seealso For managing registry files, see \code{\link{registry_file_parse}}
 #' for switching to a packaged corpus.
-#' @importFrom utils available.packages contrib.url install.packages
+#' @importFrom utils available.packages contrib.url
 #' @importFrom utils installed.packages tar
 #' @importFrom curl curl_download new_handle handle_setopt
 #' @importFrom httr http_error
@@ -103,7 +99,8 @@
 #' @importFrom tools file_path_sans_ext
 #' @importFrom zen4R ZenodoManager
 #' @importFrom cli cli_rule cli_alert_success cli_process_start cli_process_done
-#'   cli_alert_info col_cyan cli_alert_danger cli_text col_blue col_red cli_alert_warning cli_process_failed
+#'   cli_alert_info col_cyan cli_alert_danger cli_text col_blue col_red
+#'   cli_alert_warning cli_process_failed
 #' @importFrom RcppCWB cqp_is_initialized cqp_get_registry cqp_reset_registry
 #'   cl_load_corpus cqp_load_corpus
 #' @importFrom fs path_tidy path_temp
@@ -120,25 +117,30 @@ corpus_install <- function(pkg = NULL, repo = "https://PolMine.github.io/drat/",
 
   if (is.null(tarball)){
     if (isFALSE(is.null(pkg))){
-      # A pkg is stated
-      if (!pkg %in% utils::available.packages(contriburl = utils::contrib.url(repos = repo))) {
-        stop(sprintf("package '%s' not available at repo '%s'", pkg, repo))
+      
+      if (nchar(system.file(package = pkg)) == 0L){
+        warning(sprintf("Package `%s` is not available.", pkg))
+        return(invisible(FALSE))
       }
-
-      if (file.access(lib, "6") == -1){
-        stop("You do not have write permissions for directory ", lib,
-             ". Please run R with the required privileges, or provide another directory (param 'lib').")
-      }
-      install.packages(pkgs = pkg, repos = repo, lib = lib, ...)
+      
       pkg_registry <- system.file(package = pkg, "extdata", "cwb", "registry")
+      if (!dir.exists(pkg_registry)){
+        warning("Package stated by `pkg` does not include corpora.")
+        return(invisible(FALSE))
+      }
+      
       corpora <- list.files(pkg_registry)
       for (corpus in corpora){
-        regdata <- registry_file_parse(corpus = corpus, registry_dir = pkg_registry)
-        data_dir <- system.file(package = pkg, "extdata", "cwb", "indexed_corpora", corpus)
-        if (regdata[["home"]] != data_dir){
-          regdata[["home"]] <- data_dir
-          registry_file_write(data = regdata, corpus = corpus, registry_dir = pkg_registry)
-        }
+        if (verbose) cli_rule(sprintf("Copy corpus `%s`", corpus))
+        corpus_copy(
+          corpus = corpus,
+          registry_dir = pkg_registry,
+          data_dir = NULL,
+          registry_dir_new = registry_dir,
+          data_dir_new = fs::path(corpus_dir, tolower(corpus)),
+          remove = FALSE,
+          verbose = verbose, progress = interactive()
+        )
       }
       return(invisible(TRUE))
     } else {
@@ -155,37 +157,58 @@ corpus_install <- function(pkg = NULL, repo = "https://PolMine.github.io/drat/",
 
       if (verbose) cli_rule("Resolve DOI")
       if (verbose) cli_process_start("get Zenodo record referred to by DOI")
-      tryCatch(
-        zenodo_record <- ZenodoManager$new()$getRecordByDOI(doi = doi),
-        error = function(e){
-          if (verbose){
-            cli_process_failed()
-          } else {
-            cli_alert_danger(sprintf("'no Zenodo record found for DOI '%s'", doi))
-          }
+      # tryCatch(
+      #   zenodo_record <- ZenodoManager$new()$getRecordByDOI(doi = doi),
+      #   error = function(e){
+      #     if (verbose){
+      #       cli_process_failed()
+      #     } else {
+      #       cli_alert_danger(sprintf("'no Zenodo record found for DOI '%s'", doi))
+      #     }
+      #   }
+      # )
+      # 
+      # if (!exists("zenodo_record")){
+      #   return(invisible(FALSE)) # unlikely scenario that can only result from error detected by tryCatch()
+      # } else if (is.null(zenodo_record)){
+      #   if (verbose) cli_alert_danger(sprintf("no Zenodo record found for DOI '%s'", doi))
+      #   return(invisible(FALSE))
+      # } else {
+      #   if (verbose) cli_process_done()
+      # }
+      # 
+      # zenodo_files <- sapply(zenodo_record[["files"]], function(x) x[["links"]][["download"]])
+      # tarball <- grep("^.*?_(v|)\\d+\\.\\d+\\.\\d+\\.tar\\.gz$", zenodo_files, value = TRUE)
+      # 
+      # if (length(tarball) > 1L && isTRUE(ask)){
+      #   userchoice <- utils::menu(
+      #     choices = basename(tarball),
+      #     title = "Several tarballs assumed to contain an indexed corpus are available. Which tarball shall be downloaded?"
+      #   )
+      #   tarball <- tarball[userchoice]
+      # }
+      
+      tarball <- zenodo_get_tarballurl(url = doi)
+      if (is.null(tarball)){
+        if (verbose){
+          cli_alert_danger(sprintf("no Zenodo record found for DOI '%s'", doi))
         }
-      )
-      if (!exists("zenodo_record")){
-        return(invisible(FALSE)) # unlikely scenario that can only result from error detected by tryCatch()
-      } else if (is.null(zenodo_record)){
-        if (verbose) cli_alert_danger(sprintf("no Zenodo record found for DOI '%s'", doi))
         return(invisible(FALSE))
-      } else {
-        if (verbose) cli_process_done()
       }
-
-      zenodo_files <- sapply(zenodo_record[["files"]], function(x) x[["links"]][["download"]])
-      tarball <- grep("^.*?_(v|)\\d+\\.\\d+\\.\\d+\\.tar\\.gz$", zenodo_files, value = TRUE)
-
-      if (length(tarball) > 1L && isTRUE(ask)){
-        userchoice <- utils::menu(
-          choices = basename(tarball),
-          title = "Several tarballs assumed to contain an indexed corpus are available. Which tarball shall be downloaded?"
+      if (verbose) cli_process_done()
+      
+      if (verbose) cli_alert_info(
+        sprintf(
+          "tarball to be downloaded: %s",
+          col_blue(basename(unname(tarball)))
         )
-        tarball <- tarball[userchoice]
-      }
-      if (verbose) cli_alert_info(sprintf("tarball to be downloaded: %s", col_blue(basename(tarball))))
-      zenodo_file_record <- zenodo_record[["files"]][[which(zenodo_files == tarball)]]
+      )
+      
+      # zenodo_file_record <- zenodo_record[["files"]][[which(zenodo_files == tarball)]]
+      
+      if (!is.null(checksum)) checksum <- names(tarball)[1]
+      tarball <- unname(tarball)
+      
     }
   }
 
@@ -289,12 +312,12 @@ corpus_install <- function(pkg = NULL, repo = "https://PolMine.github.io/drat/",
           "download corpus tarball {col_cyan('%s')} ... done", basename(tarball)
         )
       )
-      if (exists("zenodo_file_record")){
-        if (!is.null(checksum)){
-          if (verbose) cli_alert_warning("argument checksum is not NULL but md5 checksum can be derived from Zenodo record - using checksum issued by Zenodo")
-        }
-        checksum <- zenodo_file_record[["checksum"]]
-      }
+      # if (exists("zenodo_file_record")){
+      #   if (!is.null(checksum)){
+      #     if (verbose) cli_alert_warning("argument checksum is not NULL but md5 checksum can be derived from Zenodo record - using checksum issued by Zenodo")
+      #   }
+      #   checksum <- zenodo_file_record[["checksum"]]
+      # }
       if (isFALSE(is.null(checksum))){
         if (verbose){
           msg <- sprintf("check md5 checksum for tarball %s (expected %s)", basename(tarball), checksum)
@@ -391,9 +414,9 @@ corpus_install <- function(pkg = NULL, repo = "https://PolMine.github.io/drat/",
     
     # Ask user before overwriting existing corpus ----------------
     for (corpus in corpora){
-      if (exists("zenodo_record")){
-        version <- zenodo_record[["metadata"]][["version"]]
-      } else {
+      # if (exists("zenodo_record")){
+      #   version <- zenodo_record[["metadata"]][["version"]]
+      # } else {
         rf <- registry_file_parse(
           corpus = corpus,
           registry_dir = tmp_registry_dir
@@ -405,7 +428,7 @@ corpus_install <- function(pkg = NULL, repo = "https://PolMine.github.io/drat/",
         } else {
           version <- "unknown"
         }
-      }
+      # }
       
       if (tolower(corpus) %in% list.files(cwb_dirs[["registry_dir"]])){
         regdata <- registry_file_parse(
@@ -579,7 +602,7 @@ corpus_packages <- function(){
       vectors <- lapply(
         list.files(path = lib),
         function(pkg){
-          pkgdir <- file.path(lib, pkg)
+          pkgdir <- fs::path(lib, pkg)
           c(
             package = pkgdir,
             lib = lib,
@@ -611,8 +634,8 @@ corpus_rename <- function(old, new, registry_dir = Sys.getenv("CORPUS_REGISTRY")
 
   # rename registry file
   message("renaming registry file")
-  registry_old <- file.path(registry_dir, tolower(old), fsep = "/")
-  registry_new <- file.path(registry_dir, tolower(new), fsep = "/")
+  registry_old <- fs::path(registry_dir, tolower(old))
+  registry_new <- fs::path(registry_dir, tolower(new))
   success <- file.rename(from = registry_old, to = registry_new)
   if (!success) stop("renaming the registry file failed")
 
@@ -620,7 +643,7 @@ corpus_rename <- function(old, new, registry_dir = Sys.getenv("CORPUS_REGISTRY")
   message("renaming data directory")
   regdata <- registry_file_parse(corpus = new, registry_dir = registry_dir)
   data_directory_old <- regdata[["home"]]
-  data_directory_new <- file.path(dirname(data_directory_old), tolower(new), fsep = "/")
+  data_directory_new <- fs::path(dirname(data_directory_old), tolower(new))
   success <- file.rename(from = data_directory_old, to = data_directory_new)
   if (!success) stop("renaming the data directory failed")
 
@@ -658,12 +681,12 @@ corpus_remove <- function(corpus, registry_dir, ask = interactive(), verbose = T
   }
   for (x in list.files(data_directory, full.names = TRUE)) file.remove(x)
   file.remove(data_directory)
-  file.remove(file.path(registry_dir, tolower(corpus), fsep = "/"))
+  file.remove(fs::path(registry_dir, tolower(corpus)))
   if (verbose) cli_alert_success("corpus has been removed (registry and data files)")
   invisible(TRUE)
 }
 
-#' @details \code{corpus_as_tarball} will create a tarball (.tar.gz-file) with
+#' @details `corpus_as_tarball()` will create a tarball (.tar.gz-file) with
 #'   two subdirectories. The 'registry' subdirectory will host the registry file
 #'   for the tarred corpus. The data files will be put in a subdirectory with
 #'   the corpus name in the 'indexed_corpora' subdirectory.
@@ -671,7 +694,7 @@ corpus_remove <- function(corpus, registry_dir, ask = interactive(), verbose = T
 #' @export corpus_as_tarball
 corpus_as_tarball <- function(corpus, registry_dir, data_dir, tarfile, verbose = TRUE){
 
-  registry_file <- file.path(registry_dir, tolower(corpus), fsep = "/")
+  registry_file <- fs::path(registry_dir, tolower(corpus))
   if (!file.exists(registry_file)){
     stop(
       sprintf(
@@ -686,33 +709,39 @@ corpus_as_tarball <- function(corpus, registry_dir, data_dir, tarfile, verbose =
     data_dir
   }
 
-  if (verbose) message("... moving registry file and data files to temporary directory for creating tarball")
-  tmp_dir <- normalizePath(tempdir(), winslash = "/")
-  archive_dir <- file.path(tmp_dir, tolower(corpus), fsep = "/")
+  if (verbose)
+    cli_process_start("copy registry file and data files to temporary directory for creating tarball")
+  archive_dir <- fs::path(fs::path_temp(), tolower(corpus))
   if (file.exists(archive_dir)) unlink(archive_dir, recursive = TRUE)
   dir.create(archive_dir)
 
-  archive_registry_dir <- file.path(archive_dir, "registry", fsep = "/")
-  archive_data_dir <- file.path(archive_dir, "indexed_corpora", fsep = "/")
-  archive_corpus_dir <- file.path(archive_dir, "indexed_corpora", tolower(corpus), fsep = "/")
+  archive_registry_dir <- fs::path(archive_dir, "registry")
+  archive_data_dir <- fs::path(archive_dir, "indexed_corpora")
+  archive_corpus_dir <- fs::path(archive_dir, "indexed_corpora", tolower(corpus))
   dir.create(archive_registry_dir)
   dir.create(archive_data_dir)
   dir.create(archive_corpus_dir)
 
-  file.copy(from = registry_file, to = file.path(archive_registry_dir, tolower(corpus), fsep = "/"))
+  file.copy(
+    from = registry_file,
+    to = fs::path(archive_registry_dir, tolower(corpus))
+  )
   for (x in list.files(home_dir, full.names = TRUE)){
-    file.copy(from = x, to = file.path(archive_corpus_dir, basename(x), fsep = "/"))
+    file.copy(from = x, to = fs::path(archive_corpus_dir, basename(x)))
   }
+  if (verbose) cli_process_done()
 
-  if (verbose) message("... creating tarball")
+  if (verbose) cli_process_start("creating tarball")
   old_wd <- getwd()
   on.exit(setwd(path.expand(old_wd)))
   setwd(archive_dir)
   tar(tarfile = tarfile, compression = "gzip")
+  if (verbose) cli_process_done()
 
-  if (verbose) message("... cleaning up")
+  if (verbose) cli_process_start("cleaning up")
   setwd(path.expand(old_wd))
   unlink(archive_dir, recursive = TRUE)
+  if (verbose) cli_process_done()
 
   invisible( NULL )
 }
@@ -729,10 +758,7 @@ corpus_as_tarball <- function(corpus, registry_dir, data_dir, tarfile, verbose =
 #' @export corpus_copy
 #' @rdname corpus_utils
 #' @examples
-#' registry_file_new <- file.path(
-#'   normalizePath(tempdir(), winslash = "/"),
-#'   "cwb", "registry", "reuters", fsep = "/"
-#'   )
+#' registry_file_new <- fs::path(tempdir(), "cwb", "registry", "reuters")
 #' if (file.exists(registry_file_new)) file.remove(registry_file_new)
 #' corpus_copy(
 #'   corpus = "REUTERS",
@@ -742,24 +768,21 @@ corpus_as_tarball <- function(corpus, registry_dir, data_dir, tarfile, verbose =
 #'     "extdata", "cwb", "indexed_corpora", "reuters"
 #'   )
 #' )
-#' unlink(file.path(
-#'   normalizePath(tempdir(), winslash = "/"),
-#'   "cwb", fsep = "/"),
-#'   recursive = TRUE)
+#' unlink(fs::path(tempdir(), "cwb"), recursive = TRUE)
 corpus_copy <- function(
   corpus, registry_dir, data_dir = NULL,
-  registry_dir_new = file.path(normalizePath(tempdir(), winslash = "/"), "cwb", "registry", fsep = "/"),
-  data_dir_new = file.path(normalizePath(tempdir(), winslash = "/"), "cwb", "indexed_corpora", tolower(corpus), fsep = "/"),
+  registry_dir_new = fs::path(tempdir(), "cwb", "registry"),
+  data_dir_new = fs::path(tempdir(), "cwb", "indexed_corpora", tolower(corpus)),
   remove = FALSE,
   verbose = interactive(),
   progress = TRUE
   ){
 
-  registry_file_old <- file.path(registry_dir, tolower(corpus), fsep = "/")
+  registry_file_old <- fs::path(registry_dir, tolower(corpus))
   if (!file.exists(registry_file_old)) stop(sprintf("Aborting - registry file %s does not exist.", registry_file_old))
   if (is.null(data_dir)) data_dir <- registry_file_parse(corpus = corpus, registry_dir = registry_dir)[["home"]]
 
-  registry_file_new <- file.path(registry_dir_new, tolower(corpus), fsep = "/")
+  registry_file_new <- fs::path(registry_dir_new, tolower(corpus))
 
   if (file.exists(registry_file_new)){
     stop(sprintf("Aborting - registry file %s already exists in target registry", registry_file_new))
@@ -775,7 +798,7 @@ corpus_copy <- function(
     lapply(
       list.files(data_dir, full.names = TRUE),
       function(f){
-        file.copy(from = f, to = file.path(data_dir_new, basename(f), fsep = "/"))
+        file.copy(from = f, to = fs::path(data_dir_new, basename(f)))
         spinner$spin()
         if (remove) file.remove(f)
       }
@@ -793,7 +816,7 @@ corpus_copy <- function(
   if (length(rf[["info"]]) == 1L){
     # It is a common mistake that the info file is not stated correctly in the registry file,
     # so this is a forgiving solution to remedy errors
-    info_file_old <- file.path(data_dir, basename(rf[["info"]]))
+    info_file_old <- fs::path(data_dir, basename(rf[["info"]]))
     if (!file.exists(info_file_old)){
       info_file_guessed <- grep(
         "^.*?/(|\\.)info(\\.md|)$",
@@ -845,15 +868,9 @@ corpus_copy <- function(
 #' registry_dir_src <- system.file(package = pkg, "extdata", "cwb", "registry")
 #' data_dir_src <- system.file(package = pkg, "extdata", "cwb", "indexed_corpora", tolower(corpus))
 #'
-#' registry_dir_tmp <- file.path(
-#'   normalizePath(tempdir(), winslash = "/"),
-#'   "cwb", "registry", fsep = "/"
-#' )
-#' registry_file_tmp <- file.path(registry_dir_tmp, tolower(corpus), fsep = "/")
-#' data_dir_tmp <- file.path(
-#'   normalizePath(tempdir(), winslash = "/"),
-#'   "cwb", "indexed_corpora", tolower(corpus), fsep = "/"
-#' )
+#' registry_dir_tmp <- fs::path(tempdir(), "cwb", "registry")
+#' registry_file_tmp <- fs::path(registry_dir_tmp, tolower(corpus))
+#' data_dir_tmp <- fs::path(tempdir(), "cwb", "indexed_corpora", tolower(corpus))
 #'
 #' if (file.exists(registry_file_tmp)) file.remove(registry_file_tmp)
 #' if (!dir.exists(data_dir_tmp)){
@@ -905,7 +922,7 @@ corpus_copy <- function(
 #' )
 #' unique(str)
 #'
-#' unlink(file.path(normalizePath(tempdir(), winslash = "/"), "cwb", fsep = "/"), recursive = TRUE)
+#' unlink(fs::path(tempdir(), "cwb"), recursive = TRUE)
 corpus_recode <- function(corpus, registry_dir = Sys.getenv("CORPUS_REGISTRY"), data_dir = registry_file_parse(corpus, registry_dir)[["home"]], skip = character(), to = c("latin1", "UTF-8"), verbose = TRUE){
 
   if (to == "UTF-8") to <- "UTF8"
