@@ -10,10 +10,10 @@
 #' \code{p_attribute_huffcode}. Fourth, compress index files using
 #' \code{p_attribute_compress_rdx}.
 #' 
-#' The implementation for the first two steps (\code{p_attribute_encode} and
-#' \code{p_attribute_makeall}) is a pure R implementation (so far). These two
+#' The implementation for the first two steps (`p_attribute_encode()` and
+#' `p_attribute_makeall()`) is a pure R implementation (so far). These two
 #' steps are enough to use the CQP functionality. To run
-#' \code{p_attribute_huffcode} and \code{p_attribute_compress_rdx}, an
+#' `p_attribute_huffcode()` and `p_attribute_compress_rdx()`, an
 #' installation of the CWB may be necessary.
 #' 
 #' See the CQP Corpus Encoding Tutorial
@@ -21,11 +21,17 @@
 #' explanation of the procedure (section 3, ``Indexing and compression without
 #' CWB/Perl'').
 #' 
-#' @param corpus The CWB corpus (needed by \code{p_attribute_huffcode} and \code{p_attribute_compress_rdx}).
-#' @param registry_dir Registry directory (needed by \code{p_attribute_huffcode} and \code{p_attribute_compress_rdx}).
-#' @param token_stream A character vector with the tokens of the corpus.
-#' @param compress Logical.
-#' @param verbose Logical.
+#' @param corpus The CWB corpus (needed by `p_attribute_huffcode()` and
+#'   `p_attribute_compress_rdx()`).
+#' @param registry_dir Registry directory (needed by `p_attribute_huffcode()`
+#'   and `p_attribute_compress_rdx()`).
+#' @param token_stream A `character` vector with the tokens of the corpus. The
+#'   maximum length is 2 147 483 647 (2^31 - 1); a warning is issued if this
+#'   threshold is exceeded. See the [CWB Encoding
+#'   Tutorial](https://cwb.sourceforge.io/files/CWB_Encoding_Tutorial.pdf) for
+#'   size limitations of corpora.
+#' @param compress A `logical` value.
+#' @param verbose A `logical` value.
 #' @param method Either 'CWB' or 'R'.
 #' @param p_attribute The positional attribute.
 #' @param data_dir The data directory for the corpus with the binary files.
@@ -45,10 +51,10 @@
 #' # Create new (and empty) directory structure
 #' 
 #' tmpdir <- normalizePath(tempdir(), winslash = "/")
-#' registry_tmp <- file.path(tmpdir, "registry", fsep = "/")
-#' data_dir_tmp <- file.path(tmpdir, "data_dir", "reuters", fsep = "/")
-#' if (file.exists(file.path(data_dir_tmp, "word.corpus"))){
-#'   file.remove(file.path(data_dir_tmp, "word.corpus"))
+#' registry_tmp <- fs::path(tmpdir, "registry")
+#' data_dir_tmp <- fs::path(tmpdir, "data_dir", "reuters")
+#' if (file.exists(fs::path(data_dir_tmp, "word.corpus"))){
+#'   file.remove(fs::path(data_dir_tmp, "word.corpus"))
 #' }
 #' if (dir.exists(registry_tmp)) unlink(registry_tmp, recursive = TRUE)
 #' if (dir.exists(data_dir_tmp)) unlink(data_dir_tmp, recursive = TRUE)
@@ -111,14 +117,23 @@ p_attribute_encode <- function(
   if (!file.exists(registry_dir)) stop("registry_dir does not exist")
   data_dir <- path.expand(data_dir)
   if (!file.exists(data_dir)) stop("data_dir does not exist")
-  registry_file <- file.path(registry_dir, tolower(corpus), fsep = "/")
+  registry_file <- fs::path(registry_dir, tolower(corpus))
+  
+  if (length(token_stream) >= 2L^31L){
+    warning(
+      sprintf(
+        "The maximum corpus size is 2 147 483 647 tokens, the length of the input vector is %d which is likely to fail.",
+        length(token_stream)
+      )
+    )
+  }
   
   if (method == "R"){
     
     if (verbose) message("... writing tokenstream to disk (directly from R, equivalent to cwb-encode)")
-    corpus_file <- file.path(data_dir, paste(p_attribute, "corpus", sep = "."), fsep = "/")
-    lexicon_file <- file.path(data_dir, paste(p_attribute, "lexicon", sep = "."), fsep = "/")
-    lexicon_index_file <- file.path(data_dir, paste(p_attribute, "lexicon.idx", sep = "."), fsep = "/")
+    corpus_file <- fs::path(data_dir, paste(p_attribute, "corpus", sep = "."))
+    lexicon_file <- fs::path(data_dir, paste(p_attribute, "lexicon", sep = "."))
+    lexicon_index_file <- fs::path(data_dir, paste(p_attribute, "lexicon.idx", sep = "."))
     
     if (verbose) message("... creating indices (in memory)")
     tokenstream_factor <- factor(token_stream, levels = unique(token_stream))
@@ -176,10 +191,10 @@ p_attribute_encode <- function(
       df <- data.frame(id = ids, word = token_stream, stringsAsFactors = FALSE)
       df[["cpos"]] <- 0L:(nrow(df) - 1L)
       
-      corpus_cnt_file <- file.path(data_dir, paste(p_attribute, "corpus.cnt", sep = "."), fsep = "/")
-      corpus_rev_file <- file.path(data_dir, paste(p_attribute, "corpus.rev", sep = "."), fsep = "/")
-      corpus_rdx_file <- file.path(data_dir, paste(p_attribute, "corpus.rdx", sep = "."), fsep = "/")
-      lexicon_srt_file <- file.path(data_dir, paste(p_attribute, "lexicon.srt", sep = "."), fsep = "/")
+      corpus_cnt_file <- fs::path(data_dir, paste(p_attribute, "corpus.cnt", sep = "."))
+      corpus_rev_file <- fs::path(data_dir, paste(p_attribute, "corpus.rev", sep = "."))
+      corpus_rdx_file <- fs::path(data_dir, paste(p_attribute, "corpus.rdx", sep = "."))
+      lexicon_srt_file <- fs::path(data_dir, paste(p_attribute, "lexicon.srt", sep = "."))
       
       # generate cnt file
       cnt_array <- tapply(X = df[["cpos"]], INDEX = df[["id"]], FUN = length)
@@ -214,7 +229,7 @@ p_attribute_encode <- function(
       if (verbose) message("... running cwb-encode")
       executable <- if (.Platform$OS.type == "windows") "cwb-encode.exe" else "cwb-encode"
       system2(
-        command = normalizePath(file.path(cwb_get_bindir(), executable, fsep = "/")),
+        command = fs::path(cwb_get_bindir(), executable),
         args = c(
           sprintf("-d %s", normalizePath(data_dir)),
           sprintf("-f %s", normalizePath(vrt_tmp_file)),
@@ -234,7 +249,7 @@ p_attribute_encode <- function(
       p_attrs_old <- registry_file_parse(corpus = tolower(corpus), registry_dir = registry_dir)[["p_attributes"]] # for checking later if anything is missing
       executable <- if (.Platform$OS.type == "windows") "cwb-encode.exe" else "cwb-encode"
       cwb_encode_cmd_vec <- c(
-        file.path(cwb_get_bindir(), executable, fsep = "/"),
+        fs::path(cwb_get_bindir(), executable),
         "-d", normalizePath(data_dir),
         "-f", normalizePath(vrt_tmp_file),
         "-R", normalizePath(registry_file, mustWork = FALSE),
@@ -272,10 +287,9 @@ p_attribute_encode <- function(
   if (method == "CWB"){
     if (verbose) message("... calling cwb-makeall")
     system2(
-      command = file.path(
+      command = fs::path(
         cwb_get_bindir(),
-        if (.Platform$OS.type == "windows") "cwb-makeall.exe" else "cwb-makeall",
-        fsep = "/"
+        if (.Platform$OS.type == "windows") "cwb-makeall.exe" else "cwb-makeall"
       ),
       args = c(
         sprintf("-r %s", normalizePath(registry_dir)),
@@ -290,18 +304,16 @@ p_attribute_encode <- function(
         toupper(corpus)
       )
       system2(
-        command = normalizePath(file.path(
+        command = normalizePath(fs::path(
           cwb_get_bindir(),
-          if (.Platform$OS.type == "windows") "cwb-huffcode.exe" else "cwb-huffcode",
-          fsep = "/")
-        ),
+          if (.Platform$OS.type == "windows") "cwb-huffcode.exe" else "cwb-huffcode"
+        )),
         args = compression_cmd_args, stdout = TRUE
       )
       system2(
-        command = normalizePath(file.path(
+        command = normalizePath(fs::path(
           cwb_get_bindir(),
-          if (.Platform$OS.type == "windows") "cwb-compress-rdx.exe" else "cwb-compress-rdx",
-          fsep = "/"
+          if (.Platform$OS.type == "windows") "cwb-compress-rdx.exe" else "cwb-compress-rdx"
         )),
         args = compression_cmd_args,
         stdout = TRUE
@@ -350,7 +362,7 @@ p_attribute_encode <- function(
 #' @rdname p_attribute_encode
 p_attribute_recode <- function(data_dir, p_attribute, from = c("UTF-8", "latin1"), to = c("UTF-8", "latin1")){
   
-  p_attr_lexicon_file <- file.path(data_dir, sprintf("%s.lexicon", p_attribute), fsep = "/")
+  p_attr_lexicon_file <- fs::path(data_dir, sprintf("%s.lexicon", p_attribute))
   
   lexicon <- readBin(
     con = p_attr_lexicon_file,
@@ -366,7 +378,7 @@ p_attribute_recode <- function(data_dir, p_attribute, from = c("UTF-8", "latin1"
   writeBin(object = lexcion_hex_vec, con = p_attr_lexicon_file)
   
   # generate and write index file
-  p_attr_lexicon_index_file <- file.path(data_dir, sprintf("%s.lexicon.idx", p_attribute), fsep = "/")
+  p_attr_lexicon_index_file <- fs::path(data_dir, sprintf("%s.lexicon.idx", p_attribute))
   
   index_new <- cumsum(sapply(lexicon_hex_list, length))
   index_new <- c(0L, index_new[1L:(length(index_new) - 1L)])
