@@ -19,18 +19,19 @@
 #' # Download and install open access resource
 #' gparl_url_pub <- "https://doi.org/10.5281/zenodo.3823245"
 #' tarball_tmp <- zenodo_get_tarball(url = gparl_url_pub)
-#' corpus_install(tarball = tarball_tmp)
+#' if (!is.null(tarball_tmp)) corpus_install(tarball = tarball_tmp)
 #' 
 #' # Download and install resource with restricted access
 #' tarball_tmp <- zenodo_get_tarball(url = gparlsample_url_restricted)
-#' corpus_install(tarball = tarball_tmp)
+#' if (!is.null(tarball_tmp)) corpus_install(tarball = tarball_tmp)
 #' }
 #' @export
 #' @importFrom curl curl new_handle handle_cookies curl_fetch_memory curl_download
 #' @importFrom xml2 read_html xml_find_all xml_attr
 #' @importFrom cli col_magenta
 #' @param url Landing page at Zenodo for resource. Can also be the URL for
-#'   restricted access (?token= appended with a long key).
+#'   restricted access (?token= appended with a long key), or a DOI referencing
+#'   objects deposited with Zenodo.
 #' @param destfile A `character` vector with the file path where the downloaded
 #'   file is to be saved. Tilde-expansion is performed. Defaults to a temporary
 #'   file.
@@ -38,6 +39,8 @@
 #' @param verbose A `logical` value, whether to output progess messages.
 #' @param progress A `logical` value, whether to report progress during
 #'   download.
+#' @return The path of the downloaded resource, or `NULL` if the operation has
+#'   not been successful.
 #' @rdname zenodo
 zenodo_get_tarball <- function(url, destfile = tempfile(fileext = ".tar.gz"), checksum = TRUE, verbose = TRUE, progress = TRUE){
   
@@ -56,9 +59,7 @@ zenodo_get_tarball <- function(url, destfile = tempfile(fileext = ".tar.gz"), ch
   
   h <- new_handle()
   
-  restricted <- grepl("\\?token=", url)
-  
-  if (restricted){
+  if (grepl("\\?token=", url)){
     if (verbose) cat_rule("Download restricted resource from Zenodo")
     if (verbose) cli_process_start("get handle for restricted resource")
     
@@ -81,6 +82,10 @@ zenodo_get_tarball <- function(url, destfile = tempfile(fileext = ".tar.gz"), ch
     
     if (verbose) cli_process_done()
   } else {
+    
+    if (grepl("^10\\.5281/zenodo", url))
+      url <- sprintf("https://doi.org/%s", url)
+
     if (verbose) cat_rule("Download resource from Zenodo")
 
     trystatus <- try(page <- curl(url = url))
@@ -167,6 +172,76 @@ zenodo_get_tarball <- function(url, destfile = tempfile(fileext = ".tar.gz"), ch
   destfile
 }
 
+#' @export
+#' @rdname zenodo
+#' @details `zenodo_get_tarballurl` is a (temporary) helper function to
+#'   accomplish a temporarily bugged functionality of the zen4R package.
+zenodo_get_tarballurl <- function(url){
+  
+  stopifnot(is.character(url), length(url) == 1L)
+  
+  if (grepl("\\?token=", url)){
+    warning("Not implemented for restricted data.")
+    return(NULL)
+  }
+  if (grepl("^10\\.5281/zenodo", url)) url <- sprintf("https://doi.org/%s", url)
+  if (!grepl("10\\.5281/zenodo", url)){
+    warning("Not a Zenodo page, returning `NULL`.")
+    return(NULL)
+  }
+  
+  if (isTRUE(http_error(url))){
+    warning(sprintf("HTTP error / cannot access URL %s () ", url))
+    return(NULL)
+  }
+
+  trystatus <- try(page <- curl(url = url))
+  if (is(trystatus)[[1]] == "try-error"){
+    warning("Zenodo not available. Try again later.")
+    return(NULL)
+  }
+  
+  trystatus <- try(website <- read_html(page))
+  if (is(trystatus)[[1]] == "try-error"){
+    warning("Zenodo not available. Try again later.")
+    return(NULL)
+  }
+  
+  file_elems <- xml_find_all(website, xpath = "//a[@class='filename']")
+  if (length(file_elems) == 0L){
+    warning("Website does not reference files to download.")
+    return(NULL)
+  }
+  filenames <- sapply(
+    strsplit(
+      x = sapply(file_elems, xml_attr, attr = "href"),
+      split = "\\?download"
+    ),
+    `[[`, 1L
+  )
+  tarball_index <- grep("\\.tar\\.gz", filenames)
+  if (length(tarball_index) > 1L){
+    warning("more than one tarball could be downloaded")
+    return(NULL)
+  }
+  if (length(tarball_index) == 0L){
+    warning("No tarball to be downloaded.")
+    return(NULL)
+  }
+  
+  tarball <- filenames[tarball_index]
+  
+  md5_el <- xml_find_first(file_elems[[tarball_index]], xpath = "../small")
+  md5sum_zenodo <- gsub("^md5:(.*?)\\s*$", "\\1", xml_text(md5_el))
+  
+  setNames(
+    fs::path("https://zenodo.org", tarball),
+    md5sum_zenodo
+  )
+}
+
+
+
 
 #' @details A sample subset of the GermaParl corpus is deposited at Zenodo for
 #'   testing purposes. There are identical open access and restricted versions
@@ -179,4 +254,4 @@ zenodo_get_tarball <- function(url, destfile = tempfile(fileext = ".tar.gz"), ch
 #' @rdname zenodo
 #' @keywords datasets
 #' @export
-gparlsample_url_restricted <- "https://zenodo.org/record/6546810?token=eyJhbGciOiJIUzUxMiIsImV4cCI6MTY1NjcxMjc5OSwiaWF0IjoxNjU0MTI1MzA5fQ.eyJkYXRhIjp7InJlY2lkIjo2NTQ2ODEwfSwiaWQiOjIzNjE2LCJybmQiOiI1NzdmNjU4MiJ9.flJUJJKQAtq0BjkUdu16PZdRCtz0buJIY1kaKFYZEGUnejUh3sGb9oowhHKSVA9ZszIygJ--F69Qsc_4vJ0ieA"
+gparlsample_url_restricted <- "https://zenodo.org/record/6546810?token=eyJhbGciOiJIUzUxMiIsImV4cCI6MTY3MjQzNzU5OSwiaWF0IjoxNjU4MzE5NzgwfQ.eyJkYXRhIjp7InJlY2lkIjo2NTQ2ODEwfSwiaWQiOjI0ODA4LCJybmQiOiI5N2RkYjdiZCJ9.Bi4bvXO1UXB7h6wT_RlhPWfesRb1CpIH2GNOQZ2Twf9M18k8tx38LBYvACVrKYmLZWTHIrVyN3yl_rCJ9s1PlA"
